summaryrefslogtreecommitdiff
path: root/src/gallium/drivers/llvmpipe/lp_rast_priv.h
diff options
context:
space:
mode:
authorKeith Whitwell <keithw@vmware.com>2009-12-13 18:17:25 +0000
committerKeith Whitwell <keithw@vmware.com>2009-12-13 18:17:25 +0000
commit663750d5564a225b4720f7ee8bea93ffb309fc88 (patch)
treed9fd2d2b09ad30fce3d617de6d33bfce4a898ee1 /src/gallium/drivers/llvmpipe/lp_rast_priv.h
parent39dd7108bf6014a8430dffc290e98c7b47432cd3 (diff)
llvmpipe: rename bins to scene
It was pretty confusing having an entity named "bin" and another named "bins", not least because sometimes there was a need to talk about >1 of the "bins" objects, which couldn't be pluralized any further... Scene is a term used in a bunch of places to talk about what a binner operates on, so it's a decent choice here.
Diffstat (limited to 'src/gallium/drivers/llvmpipe/lp_rast_priv.h')
-rw-r--r--src/gallium/drivers/llvmpipe/lp_rast_priv.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/gallium/drivers/llvmpipe/lp_rast_priv.h b/src/gallium/drivers/llvmpipe/lp_rast_priv.h
index ba14fc3675..79a90f6610 100644
--- a/src/gallium/drivers/llvmpipe/lp_rast_priv.h
+++ b/src/gallium/drivers/llvmpipe/lp_rast_priv.h
@@ -110,13 +110,13 @@ struct lp_rasterizer
char clear_stencil;
} state;
- /** The incoming queue of filled bins to rasterize */
- struct lp_bins_queue *full_bins;
- /** The outgoing queue of emptied bins to return to setup modulee */
- struct lp_bins_queue *empty_bins;
+ /** The incoming queue of scenes ready to rasterize */
+ struct lp_scene_queue *full_scenes;
+ /** The outgoing queue of processed scenes to return to setup modulee */
+ struct lp_scene_queue *empty_scenes;
- /** The bins currently being rasterized by the threads */
- struct lp_bins *curr_bins;
+ /** The scene currently being rasterized by the threads */
+ struct lp_scene *curr_scene;
/** A task object for each rasterization thread */
struct lp_rasterizer_task tasks[MAX_THREADS];